function [neto, old_max_eig] = rnn_esn_scaleeig(net, new_eig)
% [neto, max_eig] = rnn_esn_scaleeig(new_eig)
% neto    - resulting ESN network
% max_eig - new eigenvalue 
% new_eig - new eigenvalue 

IUC = net.numInputUnits;
HUC = net.numHiddenUnits;
OUC = net.numOutputUnits;
AUC = net.numAllUnits;

recurrentWeights = zeros(HUC, HUC);

numWeights = net.numWeights;
weightsDest   = [net.weights.dest];
weightsSource = [net.weights.source];
weightsDelay  = [net.weights.delay];
weightsValue  = [net.weights.value];

for wi=(1:numWeights),
    value = weightsValue(wi);
    i = weightsDest(wi);
    j = weightsSource(wi);
    if i<=IUC+1 || i>AUC-OUC, continue; end;
    if j<=IUC+1 || j>AUC-OUC, continue; end;
    recurrentWeights(i-IUC-1, j-IUC-1) = recurrentWeights(i-IUC-1, j-IUC-1) + value;    
end;

old_max_eig = max(abs(eig(recurrentWeights)));

if nargin > 1,
    recurrentWeights = recurrentWeights ./ old_max_eig .* new_eig;

    for wi=(1:numWeights),
        i = weightsDest(wi);
        j = weightsSource(wi);
        if i<=IUC+1 || i>AUC-OUC, continue; end;
        if j<=IUC+1 || j>AUC-OUC, continue; end;
        weightsValue(wi) = recurrentWeights(i-IUC-1, j-IUC-1);
    end;
    
    % max_eig = max(abs(eig(recurrentWeights)));

    for wi=(1:numWeights), net.weights(wi).value = weightsValue(wi); end;
end;

neto = net;

