% training_esn_mel - training ESN on periodic attractor of the "melody" seq

% seed random generator
rand('state', sum(100*clock));
setpath;

% unit counts (input, hidden, output)
IUC = 0;
HUC = 400;
OUC = 1;

% initialize ESN weights
% 1% of recurrent weights set to 0.4 or -0.4
% no input weights
% 100% backward weights set randomly from [-4.00, 4.00]
probInp  = [  0.00 ];
rngInp   = [  0.00 ]; 
probRec  = [  0.01 ];
rngRec   = [ -0.40 ];
probBack = [  1.00 ];
rngBack  = [  4.00 ];

% load melody (file is character array)
MEL_S = loadseq('mel.trs', 'REAL');
MEL_S = repmat(MEL_S,1,100);
MEL_S = tanh(MEL_S .* 2 - 1);

% check melody sequence length
if size(MEL_S, 2) < 1500, error('Melody sequence is too short.'); end;

% create esn network
[net, max_eig] = rnn_esn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack);
fprintf('Maximal eig. is %f\n', max_eig);

% train network using all values, noise of 1e3 is added to sequence
IP = zeros(0,1500);
TP = MEL_S(1:size(IP,2)) + (2*rand(1,size(IP,2))-1) .* 0.001;
[net, MSE, AO, ACT] = rnn_esn_train(net, IP, TP, 500, 0.0);
fprintf('Training MSE is %g\n', MSE);

% test network using 250 values of MG seq. as initial (teacher-forced) sequence
IP = zeros(0,1500);
TP = MEL_S(1:size(IP,2));
[AO, ACT] = rnn_esn_sim(net, IP, TP, 500, 0.0);
MSE = eval_mse(AO, TP);
fprintf('Testing MSE is %g\n', MSE);

% plot results
plot(TP,'g'); hold on;
plot(AO,'r'); hold on;



