% training_esn_mg_genx - training ESN on Mackey Glass time series, generate STEP values ahead

% seed random generator
rand('state', sum(100*clock));
setpath;

% unit counts (input, hidden, output)
IUC = 0;
HUC = 1000;
OUC = 1;

% initialize ESN weights
% 1% of recurrent weights set from [-0.40, 0.40]
% 100% of input weights (bias) set from [-0.20, 0.20]
% 100% backward weights set randomly from [-1.00, 1.00]
probInp  = [  1.00 ];
rngInp   = [  0.20 ]; 
probRec  = [  0.01 ];
rngRec   = [  0.40 ];
probBack = [  1.00 ];
rngBack  = [  1.00 ];

% create input and output time series
TAU = 17; % mild
% TAU = 30; % wild
if ~exist('MGS');
    MGS = tanh(createmgdde23(6000, TAU, 1000)-1);
end;

% create esn network
Lambda = 0.0;
UnitAct = 11;
[net] = rnn_esn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack, Lambda, UnitAct);
% [net, old_max_eig] = rnn_ffesn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack, 0.0, 0.75);
% fprintf('Maximal eig. is (before scaling) %f\n', old_max_eig);

% train network using 3000 values of MG seq. (ev. add noise to the target seq.)
IP = zeros(0,3000);
TP = MGS(1:size(IP,2));% + (2*rand(1,size(IP,2))-1) .* 0.0001;
[net, MSE] = rnn_esn_train(net, IP, TP, 1000, 1e-10);
fprintf('Training MSE is %g\n', MSE);

% test network using 6000 values of MG seq. as (teacher-forced) initial sequence
% generate activities STEP values ahead
STEP = 84;
IP = zeros(0,6000);
TP = MGS(1:size(IP,2));
[AO, ACT, AOP] = rnn_esn_sim_genx(net, IP, TP, 0, 0.0, STEP);
MSE = eval_mse(AO, TP);
fprintf('Testing MSE for the next value prediction is %g\n', MSE);

MSE = eval_mse(AOP, TP);
fprintf('Testing MSE for %d free run is %g\n', STEP, MSE);

% plot results
plot(AO,'r'); hold on;
plot(TP,'g'); hold on;
plot(AOP,'b'); hold on;

% plot(AO(1000:3175),'r'); hold on;
% plot(TP(1000:3175),'g'); hold on;
