% training_esn_mg_pred - training ESN on Mackey Glass time series, for prediction signal STEP values ahead

% seed random generator
rand('state', sum(100*clock));
setpath;

% prediction STEP
STEP = 5;

% unit counts (input, hidden, output)
IUC = 1;
HUC = 1000;
OUC = 1;

% initialize ESN weights
% 1% of recurrent weights set from [-0.40, 0.40]
% 100% of input weights (bias) set from [-0.20, 0.20]
% 100% backward weights set randomly from [-1.00, 1.00]
probInp  = [  1.00 ];
rngInp   = [  1.00 ]; 
probRec  = [  0.01 ];
rngRec   = [  0.40 ];
probBack = [  0.00 ];
rngBack  = [  0.00 ];

% create input and output time series
TAU = 17; % mild
% TAU = 30; % wild
if ~exist('MGS');
    MGS = tanh(createmgdde23(6000, TAU, 1000)-1);
end;

% create esn network
Lambda = 0.0;
UnitAct = 11;
[net] = rnn_esn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack, Lambda, UnitAct);
% [net, old_max_eig] = rnn_ffesn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack, 0.0, 0.75);
% fprintf('Maximal eig. is (before scaling) %f\n', old_max_eig);

% train network using 3000 values of MG seq. (ev. add noise to the target seq.)
IP = MGS(1:6000-STEP);
TP = MGS(STEP+1:6000);
[net, MSE] = rnn_esn_train(net, IP, TP, 1000, 1e-10);
fprintf('Training MSE is %g\n', MSE);

% test network using 3000 values of MG seq. as (teacher-forced) initial sequence
IP = MGS(1:6000-STEP);
TP = MGS(STEP+1:6000);
[AO, ACT] = rnn_esn_sim(net, IP, TP, 0, 0.0);
MSE = eval_mse(AO, TP);
fprintf('Testing MSE is %g\n', MSE);

% plot results

figure
plot(AO,'r'); hold on;
plot(TP,'g'); hold on;

figure
plot(TP,'g'); hold on;
plot(AO,'r'); hold on;

% plot(AO(1000:3175),'r'); hold on;
% plot(TP(1000:3175),'g'); hold on;
