% training_esn_sin7 - training ESN on sin^7 signal

% seed random generator
rand('state', sum(100*clock));
setpath;

% unit counts (input, hidden, output)
IUC = 0;
HUC = 100;
OUC = 1;

% initialize ESN weights
% 5% of recurrent weights set to 0.4 or -0.4
% no input weights
% 100% backward weights set randomly from [-1.00, 1.00]
probInp  = [  0.00 ];
rngInp   = [  0.00 ]; 
probRec  = [  0.05 ];
rngRec   = [ -0.40 ];
probBack = [  1.00 ];
rngBack  = [ -1.00 ];

% create input and output time series
IP = ones(0,500);
% TP = 0.5 .* sin((1:500)/5); 
TP = 0.5 .* sin((1:500)/5).^7; 

% create esn network
[net, max_eig] = rnn_esn_new(IUC, HUC, OUC, probInp, rngInp, probRec, rngRec, probBack, rngBack);
fprintf('Maximal eig. is %f\n', max_eig);

% train network using all values, noise of 1e5 is added to states
[net, MSE, AO, ACT] = rnn_esn_train(net, IP, TP, 100, 1e-5);
fprintf('Training MSE is %g\n', MSE);

% test network using 250 values of MG seq. as initial (teacher-forced) sequence
[AO, ACT] = rnn_esn_sim(net, IP, TP, 250, 0.0);
MSE = eval_mse(AO, TP);
fprintf('Testing MSE is %g\n', MSE);

% plot results
plot(TP,'g'); hold on;
plot(AO,'r'); hold on;



